<?php

namespace CRM\Factory;

use CRM\Traits\TQuery;
use Doctrine\ORM\EntityManager;

class CrmTermometroDeOportunidadeFactory
{
    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getOpportunityThermometer()
    {
        $sql = "SELECT
                TERM.*,
                INITCAP(OPIN.NMOPERADOR) NMPERINCLUSAO,
                INITCAP(OPAT.NMOPERADOR) NMPERULTATU
        FROM
            CRM_TERMOPORTUNI TERM
            LEFT JOIN OPERADOR          OPIN ON OPIN.NRORG = TERM.NRORG
                                        AND OPIN.CDOPERADOR = TERM.CDOPERINCLUSAO
            LEFT JOIN OPERADOR          OPAT ON OPAT.NRORG = TERM.NRORG
                                        AND OPAT.CDOPERADOR = TERM.CDOPERULTATU
        ORDER BY
        TERM.NMTERMOPORTUNI";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function saveThermometerOpportunity($params)
    {
        try {
            $sql = "INSERT INTO CRM_TERMOPORTUNI (
                NRTERMOPORTUNI,       NMTERMOPORTUNI,            CDOPERINCLUSAO,
                IDATIVO,              DSCORHEXADECIMAL,          DTULTATU,
                NRORG,                DTINCLUSAO,                CDOPERULTATU,                
                NRORGINCLUSAO,        NRORGULTATU
            ) VALUES (
                :NRTERMOPORTUNI, :NMTERMOPORTUNI,       :CDOPERINCLUSAO,
                :IDATIVO,        :DSCORHEXADECIMAL,     SYSDATE,
                :NRORG,          SYSDATE,               :CDOPERULTATU,
                :NRORGINCLUSAO, :NRORGULTATU
            )";
            $this->connection->executeStatement($sql, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function updateNewThermometer($params)
    {
        $sql = "UPDATE CRM_TERMOPORTUNI
                SET 
                    NMTERMOPORTUNI = :NMTERMOPORTUNI,
                    CDOPERINCLUSAO = :CDOPERINCLUSAO,
                    IDATIVO = :IDATIVO,
                    DSCORHEXADECIMAL = :DSCORHEXADECIMAL,
                    DTULTATU = SYSDATE,
                    NRORG = :NRORG,
                    DTINCLUSAO = SYSDATE,
                    CDOPERULTATU = :CDOPERULTATU,
                    NRORGINCLUSAO = :NRORGINCLUSAO,
                    NRORGULTATU = :NRORGULTATU
                WHERE
                    NRTERMOPORTUNI = :NRTERMOPORTUNI";

        $this->connection->executeStatement($sql, $params);
    }

    public function deleteThermometerOpportunity($params)
    {
        $sql = "DELETE
                FROM CRM_TERMOPORTUNI
                WHERE NRTERMOPORTUNI IN (" . $params . ")";

        $this->connection->executeStatement($sql);
    }
}
